# SAP Suggestions in Your Landscape Extension to the Meta Model
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-suggestions#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/sap-suggestions#prerequisites)
  * [Activating the Extension](https://help.sap.com/docs/leanix/ea/sap-suggestions#activating-the-extension)
  * [Changes Introduced with the Extension](https://help.sap.com/docs/leanix/ea/sap-suggestions#changes-introduced-with-the-extension)
  * [Viewing SAP Suggestions](https://help.sap.com/docs/leanix/ea/sap-suggestions#viewing-sap-suggestions)


Activate an optional extension to the meta model to view SAP suggestions for AI agents and applications in reports.
